Merge branch 'dccp'
[paraslash.git] / server.c
index 67d9bce4e5aea8822f5c4462af37fa2fb36c6ec1..c2ede7aa92566337c8d5644d1913da5b247ff512 100644 (file)
--- a/server.c
+++ b/server.c
@@ -21,8 +21,9 @@
 
 /** \mainpage Paraslash API Reference
  *
*  Good starting points for reading are probably \ref dbtool, \ref sender,
*  \ref receiver, \ref receiver_node, \ref filter, \ref filter_node.
  *
  */
 
@@ -47,11 +48,11 @@ INIT_SERVER_ERRLISTS;
 /** shut down non-authorized connections after that many seconds */
 #define ALARM_TIMEOUT 10
 
-/* these are exported to afs/command/dbtool */
+/* these are exported to afs.c. command.c and to all selectors */
 struct misc_meta_data *mmd;
 /** the configuration of para_server
  *
* It also contains the options for all database tools and all supported
  * senders.
 */
 struct gengetopt_args_info conf;
@@ -61,16 +62,16 @@ extern void http_send_init(struct sender *);
 extern void ortp_send_init(struct sender *);
 extern struct audio_format afl[];
 
-/** the list of supported database tools */
-struct dbtool dblist[] = {
+/** the list of supported audio file selectors */
+struct audio_file_selector dblist[] = {
        {
                .name = "random",
-               .init = random_dbtool_init,
+               .init = random_selector_init,
                .update_audio_file = NULL,
        },
        {
-               .name = "plm",
-               .init = plm_dbtool_init,
+               .name = "playlist",
+               .init = playlist_selector_init,
                .update_audio_file = NULL,
                .pre_select = NULL,
                .post_select = NULL,
@@ -78,7 +79,7 @@ struct dbtool dblist[] = {
 #ifdef HAVE_MYSQL
        {
                .name = "mysql",
-               .init = mysql_dbtool_init,
+               .init = mysql_selector_init,
                .update_audio_file = NULL,
                .pre_select = NULL,
                .post_select = NULL,
@@ -178,7 +179,7 @@ static void shm_init(void)
                goto err_out;
        mmd_mutex = ret;
 
-       mmd->dbt_num = 0;
+       mmd->selector_num = 0;
        mmd->num_played = 0;
        mmd->num_commands = 0;
        mmd->events = 0;
@@ -281,29 +282,29 @@ static void setup_signal_handling(void)
        }
 }
 
-static void init_dbtool(void)
+static void init_selector(void)
 {
        int i, ret;
 
-       mmd->dbt_change = -1; /* no change nec., set to new dbt num by com_cdt */
-       if (!conf.dbtool_given)
+       mmd->selector_change = -1; /* no change nec., set to new num by com_chs */
+       if (!conf.selector_given)
                goto random;
        for (i = 0; dblist[i].name; i++) {
-               if (strcmp(dblist[i].name, conf.dbtool_arg))
+               if (strcmp(dblist[i].name, conf.selector_arg))
                        continue;
-               PARA_NOTICE_LOG("initializing %s database tool\n",
+               PARA_NOTICE_LOG("initializing %s audio file selector\n",
                        dblist[i].name);
                ret = dblist[i].init(&dblist[i]);
                if (ret < 0) {
                        PARA_WARNING_LOG("%s", PARA_STRERROR(-ret));
                        break;
                }
-               mmd->dbt_num = i;
+               mmd->selector_num = i;
                return;
        }
-       PARA_WARNING_LOG("%s", "falling back to the random dbtool\n");
+       PARA_WARNING_LOG("%s", "falling back to the random selector\n");
 random:
-       mmd->dbt_num = 0;
+       mmd->selector_num = 0;
        dblist[0].init(&dblist[0]); /* always successful */
 }
 
@@ -356,7 +357,7 @@ static unsigned do_inits(int argc, char **argv)
        /* become daemon */
        if (conf.daemon_given)
                daemon_init();
-       init_dbtool();
+       init_selector();
        PARA_NOTICE_LOG("%s", "initializing audio file sender\n");
        /* audio file sender */
        afs_init();
@@ -374,21 +375,21 @@ static unsigned do_inits(int argc, char **argv)
        return sockfd;
 }
 
-static void handle_dbt_change(void)
+static void change_selector(void)
 {
-       int ret, old = mmd->dbt_num, new = mmd->dbt_change;
+       int ret, old = mmd->selector_num, new = mmd->selector_change;
 
        dblist[old].shutdown();
        ret = dblist[new].init(&dblist[new]);
-       mmd->dbt_change = -1; /* reset */
+       mmd->selector_change = -1; /* reset */
        if (ret >= 0) {
-               mmd->dbt_num = new;
+               mmd->selector_num = new;
                return;
        }
        /* init failed */
-       PARA_ERROR_LOG("%s -- switching to the random dbtool\n", PARA_STRERROR(-ret));
+       PARA_ERROR_LOG("%s -- switching to the random selector\n", PARA_STRERROR(-ret));
        dblist[0].init(&dblist[0]);
-       mmd->dbt_num = 0;
+       mmd->selector_num = 0;
 }
 
 /*
@@ -400,8 +401,8 @@ static void handle_sighup(void)
        close_log(logfile); /* gets reopened if necessary by parse_config */
        logfile = NULL;
        parse_config(1); /* reopens log */
-       mmd->dbt_change = mmd->dbt_num; /* do not change dbtool */
-       handle_dbt_change(); /* force reloading dbtool */
+       mmd->selector_change = mmd->selector_num; /* do not change selector.. */
+       change_selector(); /* .. just reload */
 }
 
 static void status_refresh(void)
@@ -463,8 +464,8 @@ repeat:
                        &max_fileno,
                        &rfds, &wfds);
        }
-       if (dblist[mmd->dbt_num].pre_select) {
-               ret = dblist[mmd->dbt_num].pre_select(&rfds, &wfds);
+       if (dblist[mmd->selector_num].pre_select) {
+               ret = dblist[mmd->selector_num].pre_select(&rfds, &wfds);
                max_fileno = MAX(max_fileno, ret);
        }
        mmd_unlock();
@@ -473,10 +474,10 @@ repeat:
        err = errno;
        //PARA_DEBUG_LOG("%s: select returned  %i\n", __func__, ret);
        mmd_lock();
-       if (mmd->dbt_change >= 0)
-               handle_dbt_change();
-       if (dblist[mmd->dbt_num].post_select)
-               dblist[mmd->dbt_num].post_select(&rfds, &wfds);
+       if (mmd->selector_change >= 0)
+               change_selector();
+       if (dblist[mmd->selector_num].post_select)
+               dblist[mmd->selector_num].post_select(&rfds, &wfds);
        if (ret < 0 && err == EINTR)
                goto repeat;
        if (ret < 0) {
@@ -511,7 +512,7 @@ repeat:
                case SIGTERM:
                        PARA_EMERG_LOG("terminating on signal %d\n", sig);
                        kill(0, SIGTERM);
-                       dblist[mmd->dbt_num].shutdown();
+                       dblist[mmd->selector_num].shutdown();
                        mutex_destroy(mmd_mutex);
                        shm_detach(mmd);
                        shm_destroy(mmd_shm_id);
@@ -21,8 +21,9 @@
 /** \mainpage Paraslash API Reference
  *
- *  Good starting points for reading are probably \ref dbtool, \ref sender,
- *  \ref receiver, \ref receiver_node, \ref filter, \ref filter_node.
+ *  Good starting points for reading are probably \ref audio_file_selector,
+ *  \ref sender, \ref receiver, \ref receiver_node, \ref filter, \ref
+ *  filter_node.
  *
  */
@@ -47,11 +48,11 @@ INIT_SERVER_ERRLISTS;
 /** the configuration of para_server
  *
- * It also contains the options for all database tools and all supported
+ * It also contains the options for all audio file selectors and all supported
  * senders.
 */